# Community-led Open Publication Infrastructures for Monographs (COPIM): Annual Report - Year 1 (2019-2020)

Tobias Steiner, Janneke Adema

**Participating organisations**

Partners: Coventry University (Lead); Birkbeck, University of London; Lancaster University; Trinity College, Cambridge; Loughborough University Library; UC Santa Barbara Library; Open Book Publishers; Punctum Books; The Directory of Open Access Books; Jisc.

Collaborators: ScholarLed (incl. Mattering Press, Open Book Publishers, Open Humanities Press, Meson Press, Punctum Books), The British Library, The Digital Preservation Coalition.

COPIM is supported by the Research England Development Fund (REDFund) as a major development project in the Higher Education sector with significant public benefits.

COPIM is also supported by [Arcadia](https://www.arcadiafund.org.uk/) – a charitable fund of Lisbet Rausing and Peter Baldwin. Arcadia supports charities and scholarly institutions that preserve cultural heritage and the environment. Arcadia also supports projects that promote open access, and all of its awards are granted on the condition that any materials produced are made available for free online. Since 2002, Arcadia has awarded more than \$633 million to projects around the world.

| Preparation Slip  |       *Name*                         |    *Organisation*              |     *Date*        |
|-------------------|-----------------------------|----------------|------------|
|                   |                             |                |            |
| **From:**         | Tobias Steiner              | COVU           | 07/10/2020 |
| **Edited by:**    | Janneke Adema               | COVU           | 12/10/2020 |
| **Reviewed by:**  | Gareth Cole                 | LOUGHU         | 19/10/2020 |
|                   | Lucy Barnes                 | OBP            | 19/10/2020 |
|                   | Dan Rudman                  | punctum        | 19/10/2020 |
|                   | Joe Deville                 | LCU            | 19/10/2020 |
|                   | Vincent W.J. van Gerven Oei | punctum        | 15/10/2020 |
|                   | Tom Grady                   | BBK            | 14/10/2020 |
|                   | Izabella Penier             | LCU            | 15/10/2020 |
|                   | Graham Stone                | Jisc           | 14/10/2020 |
|                   | Agata Morka                 | OBP            | 13/10/2020 |
| **Approved by:**  | Janneke Adema, Gary Hall    | COVU           | 19/10/2020 |
| **For delivery:** | Janneke Adema               | COVU           | 20/10/2020 |


## Executive Summary

COPIM is committed to exploring possible solutions to some of the most pressing barriers currently preventing small publishers from interfacing with large-scale organisations and processes. As a result, COPIM is developing a significantly enriched not-for-profit and open source ecosystem for OA (open access) book publishing that will support and sustain a diversity of publishing initiatives and models, particularly within Humanities and Social Sciences (HSS) publishing.

The adoption of alternative infrastructures, business models, preservation structures, and governance procedures to be scoped and developed through COPIM will enable increased economic resilience and enhanced capacities for open access books at smaller and larger scales. COPIM's approach will offer Higher Education institutions and HSS researchers sustainable publishing models they control, increased publishing options, and new revenue streams and cost reductions to build a more equitable horizontal and co-operative knowledge sharing community. During the first year of the project, COPIM has established a solid foundation in the areas of collaborative research, infrastructure development, project management, and outreach and community building. Successfully adapting its approach to face a set of unforeseen challenges, the project has achieved the majority of its deliverables and milestones across all work packages, in some areas even outperforming the initial goals set.

The list of key output and activities delivered includes:

-   the **publication of two major scoping reports**;

  -   the successful organisation and documentation of **eleven workshops** with **more than 120 national and international high-profile stakeholders representing 18 countries**;
  -   the successful switch to an online-only approach due to COVID-19, which now includes the setup and iterative extension of an **Outreach and Dissemination network** that is combining a variety of channels including social media and open community platforms;

-   and the initial setup and continuous further development of a resource to make [open access book metadata](https://github.com/thoth-pub) available in an open, transparent and participatory way, which will integrate into the larger Open Dissemination System, to be developed in Years 2 and 3.

The project has successfully fostered engagement with the work packages’ variety of stakeholders (i.e. librarians, publishers, authors, technology providers and the general public), bringing together key experts and those interested in learning more about scholar-led not-for-profit OA book publishing. Next to its own event organisation and outreach activities, COPIM has also been invited to participate in a variety of external conferences, events, and networks by organisations and projects such as Invest in Open Infrastructure, OASPA, OPERAS, LIBER, the Next Generation Libraries Project, and the Open Access Book Network, The British Library, OpenAIRE, COAR, and EIFL.

The overall progress made during this first year seems particularly noteworthy as the project not only had to face the challenges of first-year setup, including early minor delays in staff recruitment, onboarding, and the organisation of basic project management and governance structures; COPIM was also faced with a set of unprecedented challenges that permeated all aspects of the delivery process and will potentially impact the remainder of the project going forward. The main challenges include Brexit and its impact on the economy—and corresponding uncertainties—and the impact of the COVID-19 pandemic, with all systemic consequences that this entails.

Building on the foundational research, project management structures and outreach networks that have been successfully established in Year 1, the project is eager to continue on its path to further developing the envisioned infrastructures, pilot cases, governance structures, and outreach programmes it is set to deliver in Years 2 and 3.

## Analysis of progress against timetable: overview

This report is the first of three annual reports to be submitted to [Arcadia](https://www.arcadiafund.org.uk/) – a charitable fund of Lisbet Rausing and Peter Baldwin, by the Community-Led Open Publication Infrastructures for Monographs (COPIM) project.

### Background

COPIM is committed to exploring possible solutions to some of the most pressing barriers preventing small publishers from interfacing with large- scale organisations and processes. Towards that goal COPIM is now looking to scope, develop and build the critical underlying modular components to support the sustainable publication of OA books, comprising:

-   **infrastructures** (WP2 and 5), including a fully functional consortial library funding platform and an Open Dissemination System (ODS) for the integration of OA books into discovery systems;

-   **business models** (WP2 and 3), including an online toolkit and two pilot cases with existing OA publishers and publishers wanting to transition to OA monographs;

-   **governance procedures** (WP4), including community-approved best practices for the governance of open source collectively-owned infrastructures and OA presses;

-   **re-use strategies** (WP6) to promote OA book content discovery, interaction, and reuse as well as the development and interaction with emergent genres of scholarship;

-   **preservation structures** (WP7) for the archiving of complex OA books;

-   **outreach programs** (all WPs) including extensive knowledge exchange activities with a range of HE and publishing stakeholder partners.

These systems and infrastructures will be open, collectively managed for the common good, and they will map onto existing publishing workflows (e.g. from publisher to library) while also re-engineering them.

As a result, COPIM is developing a significantly enriched not-for-profit and open source ecosystem for OA book publishing that will support and sustain a diversity of publishing initiatives and models, particularly within HSS publishing.

### Achievements

During its first year, the project has focused on establishing a solid foundation for collaborative research, infrastructure development, project management, and outreach. COPIM’s work packages have done so predominantly by engaging in community building and by collecting research data, conducting landscape studies by means of several scoping reports and consulting stakeholders via workshops and participation in external events. All of this is understood to be in preparation and support of the infrastructures, the pilot cases, and the governance and preservation structures that will be developed in Year 2 and 3 of the project. In parallel, the project has been developing its underlying philosophy and organisational principle of ‘scaling small’,[1] which informs its overall work, engaging the work packages in a dialogue around how this can be implemented and put into practice.

[^1]: This “principle eschews standard approaches to organisational growth that tend to flatten community diversity through economies of scale, and instead puts forward the idea that scale can be nurtured through intentional collaborations between community-driven projects that promote a bibliodiverse ecosystem while providing resilience through resource sharing and other kinds of collaboration.” (Adema and Moore, 2020, forthcoming)

COPIM has been able to successfully meet the majority of activities and outputs set out in its proposal. The main results achieved during COPIM’s first year include:

-   the **publication of two major scoping reports**, comprising:

    -   the WP3 Scoping Report [Revenue Models for Open Access Monographs](https://doi.org/10.5281/zenodo.4011835), published in September 2020, which provides a concise analysis of the open access economic models in use today in scholarly publishing, comprising a diachronic overview and synthesis of studies published on the subject in the past ten years, also updating these research findings to include the environment and economics of OA publishing in 2020;

    -   and the WP5 Scoping Report [Building an Open Dissemination System](https://doi.org/10.5281/zenodo.3961563), published in July 2020, which discusses the distribution of books via the traditional library supply chain and new forms of digital dissemination before looking at metadata in depth, with metadata creation and types being investigated in order to form a number of key recommendations for WP5.

-   the successful organisation and documentation of **eleven** [workshops](https://www.copim.ac.uk/events/) engaging with more than **120 national and international stakeholders** from the UK, the US, Africa, Latin America, Australia, New Zealand, and Europe to establish communities on a variety of overarching open access book-related topics;

-   the initial setup and continuous further development of an [Open Dissemination System](https://github.com/thoth-pub), a resource to make open access book metadata available in an open and transparent way;

-   and the setup and iterative extension of a set of **Outreach and Dissemination activities** that are combining a variety of channels including social media and open community platforms.

### Activities and Outputs

[Please refer to the [Appendix](#appendix) for a full list of activities and outputs in Year 1]

The project has successfully fostered engagement with the work packages’ variety of stakeholders (i.e. librarians, publishers, authors, technology providers, and the general public), bringing together key experts and those interested in learning more about scholar-led not-for-profit OA book publishing. In addition to the workshops organised by COPIM, the team has also supported and contributed to events and workshops held by external stakeholders and organisations working towards goals that are mutually beneficial (following the previously mentioned principle of ‘scaling small’, see footnote 1). These organisations include:

-   [Invest in Open Infrastructure](https://investinopen.org/)'s [Future of Scholarship](https://investinopen.org/2020/06/17/reopening-plans-open-scholarship-call-for-participation.html) project;

-   [Knowledge Futures Group](https://www.knowledgefutures.org/)'s Community Summit;

-   the Open Access Scholarly Publishers Association ([OASPA](https://oaspa.org/));

-   [OPERAS](https://operas.hypotheses.org/);

-   Ligue des Bibliothèques Européennes de Recherche – Association of European Research Libraries ([LIBER](https://libereurope.eu/));

-   the [Next Generation Libraries Project](https://educopia.org/next-generation-library-publishing/);

-   [The British Library](https://blogs.bl.uk/living-knowledge/2020/10/open-and-engaged-conference-2020-inequities-in-scholarly-communications.html);

-   [OpenAIRE](https://www.openaire.eu/events/eventdetail/772/53%7C54%7C55%7C56%7C57%7C58%7C272%7C303/equity-and-inclusion-community-owned-infrastructures-for-open-science), [COAR](https://www.coar-repositories.org/event/equity-and-inclusion-community-owned-infrastructures-for-open-science/), and [EIFL](https://www.eifl.net/);

-   and the [Open Access Books Network](https://hcommons.org/groups/open-access-books-network/) platform.

As part of this, COPIM has also set up new collaborations to [build innovative forms of open online community events](https://doi.org/10.21428/785a6451.370f67b5), evident from the team’s work with the [Coko Foundation](https://coko.foundation/) in creating the [Open Publishing Fest](https://www.openpublishingfest.org/calendar.html). In two exciting weeks that were filled with [more than 150 events](https://openpublishingfest.org/archives.html), Open Publishing Fest allowed COPIM members and the larger scholarly communications community to discover new formats to share their ongoing work with a more global audience, and presented an opportunity to expand COPIM’s community to those not only working in scholarship but also in open source software development, open government, and the arts.

### Impact

It is safe to say that the impact achieved across all work packages during this first year has exceeded the team’s initial expectations. Engagement with key stakeholders (including publishers, knowledge managers, and librarians) from the UK, the United States, Europe, Africa, Australia and New Zealand has been very fruitful, and the interest in COPIM’s approach from external stakeholders is mirrored in the consistently-high engagement numbers that are available from the list of Outputs (see Appendix) generated by the project so far.

The Outreach programme has also been established over the course of the first year, with the amount of engaged library stakeholders exceeded by more than 100% compared to the initial plan. Outreach and Dissemination Activities are now made visible both on the newly-established [project website](https://www.copim.ac.uk/) under a major .ac.uk domain, and COPIM’s [Open Documentation site](https://copim.pubpub.org/), with a list of detailed output available in the [Appendix](#addendum) section.

### Challenges

The overall progress made during this first year seems particularly noteworthy given that, with a nominal start in November 2019, the project had to factor in minor delays in staff recruitment, onboarding, and the setting up of basic project management and governance structures. Next to that, the project also had to face a set of unprecedented challenges that permeated all aspects of the delivery process. The main challenges include:

-   **Brexit**, and its impact on the economy, with the British Pound's intermittent loss in value, which has been particularly affecting project payments to US- and EU-based partners; and corresponding uncertainties around the viability of contractual setups with international partners (EU, US), and their future sustainability due to the increased possibility of changing legislation (e.g. GDPR and continuing uncertainty around the UK’s future (non-)compliance[^2]).

    [^2]: see e.g. [Information Commissioner’s Office, FAQ](), and “proposed rewriting of data protection rules said to put vital cooperation in doubt”: [The Guardian, Sept 25, 2020]().

-   The impact of the **COVID-19 pandemic**. COVID-19’s impact on the Higher Education sector is becoming more and more tangible, with already-shrinking budgets available to a sizeable portion of COPIM’s stakeholders,[^3] which in turn might mean less willingness to engage in the transformative approach that COPIM is proposing. On a more pragmatic level, this had an impact on the project’s recruitment strategy, as many of the partners were seeing recruitment limitations enforced in their institutions, which in turn led to delays in getting some of the open WP positions filled. The pandemic also created a set of challenges for the team, including the switch to working from home, and the necessity of dealing with a notable increase in care duties, which impacted on members’ availability and called for a flexible approach to meeting management and general workflows in the project. Next to that, switching from in-person stakeholder workshops to new modes of engagement via online events that would still yield enough data to inform the research planned in the work packages, presented new opportunities, but also brought a completely new set of challenges that the team had to face. A case in point has been COPIM’s need to [move the first cross-WP workshop](https://copim.pubpub.org/pub/copim-publishers-workshop-march-2020-report) that had been planned as a two-day in-person event to online at the last minute, with no benchmarks of how to facilitate such a pivot available at the time.

    [^3]: With the Institute for Fiscal Studies estimating that UK HE‘s losses will be between £3 billion and £19 billion in one year: [https://www.ifs.org.uk/publications/14919]().

Hence the project’s first year has been fraught with a lot of uncertainty and shifting parameters. This has been particularly evident on the level of Outreach & Engagement activities: the pandemic has largely inhibited COPIM’s ability to meet experts in the same physical space for the purpose of building community around the project. This also holds true for the team’s engagement in internal team-building, as well as face-to-face meetings that would have been part of (e.g. the project’s biannual meetings). Approaching these challenges in a creative way, the team has succeeded in establishing a number of alternative channels for interaction, networking, and knowledge sharing. Next to that, the team has iteratively updated the Risk Register, which will be attached to this report’s Appendix section.

The new modes of engagement made necessary by the pandemic have also led to an increase in workshops planned by COPIM members. In many respects, the updated mode of delivery has proven beneficial for COPIM, with increased efficiency in organising logistics and participants through a more streamlined setup also allowing the project team to include participants from a wider range of geographic locations, and further extending stakeholder engagement to regions that tend to be underrepresented in the larger OA discourse.[^4]

[^4]: See e.g. Joseph, Andrew. 2015. “Scholarly Publishing in South Africa: The Global South on the Periphery”. *Insights* 28 (3): 62–68. DOI: [https://doi.org/10.1629/uksg.253](https://doi.org/10.1629/uksg.253). Or Guédon, Jean-Claude . *Open Access and the divide between “mainstream” and “peripheral” science*, 2008, book chapter in: Como gerir e qualificar revistas científicas (2007, in Portuguese). [https://core.ac.uk/display/11882978](https://core.ac.uk/display/11882978). and Raju, R., & Pietersen, J. (2017). Library as Publisher: From an African Lens. *Journal of Electronic Publishing*, 20(2). [https://doi.org/10.3998/3336451.0020.203]([https://doi.org/10.3998/3336451.0020.203).

It needs to be noted, though, that while the move to online workshops has allowed for greater responsiveness, focus, and participation, deficits of this new mode of engagement also become apparent in the sometimes burdensome increase of video meetings, with [Zoom fatigue](https://www.nationalgeographic.com/science/2020/04/coronavirus-zoom-fatigue-is-taxing-the-brain-here-is-why-that-happens/) always looming around the corner, and the loss of rich social interaction that in-person, face-to-face meetings offer, with the corresponding lack of ability to engage more with possible stakeholders in order to foster deeper in-person networking.

Nonetheless, it is safe to say that the underlying systemic problems that have become apparent during the early months of the pandemic have also brought the team to reflect more on the ways in which the project work is made discoverable and reusable in a transparent manner.

### Outlook

All of this is now made visible on the [project website](https://www.copim.ac.uk/) and COPIM’s [Open Documentation site](https://copim.pubpub.org/), both of which are regularly updated to establish a clear timeline of COPIM’s research, findings, and processes, all of which is made openly available to the general public. In the same vein, COPIM is now beginning to work across all its work packages to establish a sustainable archiving workflow to make all project outputs available as early as possible, in an open and transparent manner, and under permissive open licenses.

Overall, the foundational research, project management structure, and outreach networks that have been established in Year 1 are now ready to support the development of the infrastructures, pilot cases, and the governance and preservation structures the team is already working on and will continue to do so in Years 2 and 3.

Focusing on the output categories of *Collaborative Research*, *Infrastructure Development*, and *Outreach Activities & Community Building*, the following paragraphs will present the project’s progress in more detail and with reference to each of the work packages. Next to that, concise lists of *Outcomes* and *Impact* achieved over the first year are provided as part of the Appendix to this report.  


## WP2. Revenue Infrastructures and Management Platform

WP2 is working to develop and launch a modular, scalable revenue generation and management platform for open access books, to be made available to publishers and libraries. As envisioned, it will be scoped and built by a team of publishers, knowledge managers, and librarians working in partnership to develop new funding channels for open access books.

To that end, WP2 has been focusing on the scoping element in its first year, working to organise a range of workshops with a large variety of stakeholders from the library and publishing world, and to produce a scoping report.

### Outreach Activities

While WP2 has faced an early delay in organising workshops due to the required shift from in-person to online events, the Work Package has rebounded from that early deferral and has now successfully expanded the originally-envisioned number of workshops to include scoping workshops in many European countries.

The first workshop — which originally had been envisioned to take place in Cambridge, but then coincided with the pandemic turning critical — was turned into an inter-WP online event, the [COPIM Publishers Workshop](https://www.copim.ac.uk/events/200316-publishers-workshop/), held on March 16. It served as an initial test bed to discuss ideas around a book publishing revenue and management platform. This was then expanded upon in three more scoping workshops held on [May 13](https://www.copim.ac.uk/events/200513-library-publishers-us-workshop/), [June 16](https://www.copim.ac.uk/events/200616-library-publishers-uk-workshop/), and [July 7](https://www.copim.ac.uk/events/200707-library-publishers-us-workshop/), so as to be able to collate different perspectives from a variety of regions and stakeholder positions.

Two reports reflecting on the outcomes of these workshops with different regional foci have subsequently been published:

-   the [first report considers the specific context of the United States of America](https://doi.org/10.21428/785a6451.c6005f3a);

-   the [second report reflects outcomes of the workshop held with UK stakeholders](https://copim.pubpub.org/pub/sketching-a-direction-of-travel-an-update-from-wp-2).

The list of workshops has then seen further extension through a partnership with the EU-funded OPERAS-P project, which has led to four more workshops in Germany ([July 30](https://www.copim.ac.uk/events/200730-library-publishers-german-workshop/)) and Poland ([August 13](https://www.copim.ac.uk/events/200813-library-publishers-polish-workshop/)) as well as with stakeholders from the Nordic countries ([September 30](https://www.copim.ac.uk/events/200930-library-publishers-scandinavian-workshop/)), and Southern Europe ([October 08](https://www.copim.ac.uk/events/201008-library-publishers-southern-european-workshop/)). The results of these workshops have been documented in a further [collection of reports](https://copim.pubpub.org/workshops), while all of them will inform a separate scoping report currently being compiled by the COPIM-OPERAS-P liaison. This report will focus on European libraries’ engagement with OA books, investigating OA books policies, funding structures, integration of OA books into library catalogues, engagement of libraries with OA in general, and a survey of scholar-/academic-/library-led activities in the European countries represented in the study.

### Collaborative Research

WP2 has seen some deferral in being able to complete the **Scoping Report**, as delay in staff recruitment and the overall substantial impact of COVID-19 on team members’ availability meant that some of the workload had to be re-prioritized. As the Work Package is now consolidating this early delay and subsequent outputs are not directly affected by this, the team is committed to continue according to the original schedule.

The Scoping Report is currently nearing the stage of a first draft, with an estimated completion in project month (PM) 13.

### Infrastructure Development

WP2 has drafted a first set of **Design Specs** for the future platform. The variety of workshops have helped to inform the scope of these specifications tremendously. These have been agreed internally by the team and are due to be signed off with the developer this week. In keeping with our principles of open documentation, these will be published shortly thereafter, by the end of PM12. The slight postponement in publishing these has primarily been caused by one project partner’s delay in getting the external developer formally set up as a contributor. This was finally confirmed earlier this month.

## WP3. Knowledge Exchange and Piloting Alternative Business Models

WP3 is dedicated to knowledge exchange and transfer, as part of the project’s central commitment to dissemination. It builds pathways to impact with relevant stakeholders from across the sector, including publishers (New) University Presses, library-presses, scholar-led presses, academics, learned societies, and open technology developers.

To that end, WP3 has been focusing on initial stakeholder engagement so as to formally scope its underlying topic of OA business models, and has then started to work on the research output.

In parallel, steps have been taken to investigate legal and contractual prerequisites at the partner institutions for setting up a conversion pilot case to transition the business models of at least two extant publishers to new open access amenable models. Substantial progress has been made there and WP3 has formally engaged with one publisher, with a second publisher in final stages of talks. WP3 is now working to launch their first pilot case study by the end of 2020.

### Outreach Activities & Community Building

Similar to WP2, WP3’s first workshop was part of an inter-WP online event led by WP5 — the [COPIM Publishers Workshop](https://www.copim.ac.uk/events/200316-publishers-workshop/), held on March 16. For WP3, this served as a valuable first scoping opportunity to engage with participants to reflect on their experiences with revenue models, but also cost models, in an open-access world of books. A [detailed workshop report](https://doi.org/10.21428/785a6451.c77576a6) has subsequently been published on the COPIM Open Documentation site.

### Collaborative Research

Closely working with colleagues in WP2, Work Package 3 is committed to a research project to investigate existing business models for OA monographs as well as to provide critical resources for the development of new business models.

While WP3 does not formally have research output scheduled for the first year of the project, the work package has been able to streamline its efforts on this segment, thus enabling the team to deliver its main research output ahead of schedule. The resulting **Scoping Report**, [Revenue Models for Open Access Monographs](https://doi.org/10.5281/zenodo.4011835), published in September 2020, provides a concise analysis of the open access economic models in use today in scholarly publishing, comprising a diachronic overview and synthesis of studies published on the subject in the past ten years, and also updating these research findings to include the environment and economics of OA publishing in 2020.

The scoping report is envisioned to become one component of a practical ‘toolkit’ that WP3 is developing to enable interested presses to convert to OA-amenable business models that then allow for the establishing of sustainable OA monograph publishing outlets.  


## WP4. Community Governance

Work Package 4 is developing the governance procedures to support COPIM’s open publication ecosystem for monographs. During the first year, WP4 has been working to establish a solid conceptual base through both research and outreach activities. It is on this base that durable organisational structures for the coordination, governance and administrative support of the project’s community-owned infrastructures will be developed.

### Outreach Activities & Community Building

This includes developing new avenues of outreach, communication and partnership with diverse stakeholders in open research with a shared interest in these infrastructures, creating genuine community involvement and collective control, ensuring the infrastructures won’t be governed by a particular commercial interest.

One substantial element of these efforts has been the timely organisation of a [Community Governance Workshop](https://www.copim.ac.uk/events/200501-community-governance-workshop/), facilitated by UCSB Library in close collaboration with Coventry University as an online event in May 2020. The workshop brought together governance experts, key stakeholders in OA book publishing, and representatives from allied large community-led projects, including AmeliCA, SPARC, the California Digital Library, éditions science et bien commun, and the Educopia Institute, to collaboratively explore what the governance procedures of COPIM’s open publication ecosystem for monographs should look like, and to begin thinking about developing models to sustain the governance of the infrastructure as a community-based OA service organisation. A [two](https://doi.org/10.21428/785a6451.6a3a2ca2)-[part](https://doi.org/10.21428/785a6451.dfe7dc68) report reflecting on the outcomes of this workshop has also been published.

WP4 has also successfully established a **Publisher-Librarian working group** — set up on the [Humanities Commons platform](https://hcommons.org/groups/copim-infrastructure-governance-working-group/) — which is advising the project on:

-   a) the long-term management of consortial library funding programs;

-   b) the identification and fostering of library-publisher experiments and projects that emphasise horizontal and cooperative knowledge-sharing between stakeholders (librarians, publishers, and researchers).

An outreach plan has been developed for the working group for Fall and Spring of 2020/2021, which has been shared with the participants.

Internal interviews with the various COPIM WPs are also being conducted to identify the various governance needs within COPIM with respect to the infrastructures, models, and pilot cases the project is developing.

### Collaborative Research

The team has begun work on its research on best practices for the governance of open source community-owned infrastructures. The team is working on a mapping of organisational governance models, and some first reflections have been shared in a [research blogpost](https://copim.pubpub.org/pub/community-governance-explored/release/3) and as part of a series of conference papers. In addition to that, Janneke Adema and Samuel Moore have written an article on ‘Scaling Small’, the philosophy and organisational principle informing the COPIM project, which is currently under review at the OA journal *Westminster Papers in Communication and Culture* (expected publication December 2020). Sherri Barnes has written an essay for *College and Research Libraries News* on COPIM as a Transformative OA Monograph Initiative (expected publication December 2020).

The research is progressing well, with the caveat that the team has decided to realign the two Year 2 scheduled deliverables’ publication sequence so that the research report on governance models (D4.2) will be released prior to the identification of the official policies and procedures for self-governance and administrative management of the community-owned infrastructure (D4.1).

## WP5. Building an Open Dissemination System

Guided by the perspective of new and emerging not-for-profit open access presses that have not yet been sufficiently integrated into existing discovery systems, knowledge bases, and supply routes, the aim of WP5 is to develop methods and systems to better integrate the catalogues of open access publishers into curated research records. The implementation of ‘best practices’ workflows for open access book publishers will allow their catalogues to be better integrated into the scholarly record (discoverability, reach, persistence), increasing the impact of open access books. To support this, WP5 is building an Open Dissemination System (ODS) for open access books and a shared ‘best practices’ digital catalogue.

Similar to the other work packages, WP5 has also been impacted by the pandemic, leading to a minor delay in the delivery of output that had been scheduled for the first year of the project.

### Outreach Activities & Community Building

Operating in close collaboration with WPs 2 and 3, WP5 has led the organisation of the Cambridge workshop. Focusing on questions of dissemination and discovery of open access books, a subsequent [two](https://doi.org/10.21428/785a6451.4657252e)-[part](https://doi.org/10.21428/785a6451.3cc46720) report was published shortly after.

Against the backdrop of the pandemic, the team decided to realign its outreach strategy, with research for the emerging scoping report and the parallel development of an Open Dissemination System (ODS) making a rescheduling of the second workshop to a later stage the preferred option. Building on the findings and recommendations synthesized in the scoping report, and using the ODS prototype as a showcase, this workshop targeted at discovery vendors is now envisioned to take place in the first half of 2021.

### Collaborative Research

While the publication of WP5’s research output has seen an initial delay due to the pandemic, the team decided to publish a time-stamped version of this key deliverable, while simultaneously continuing to further develop the document as the project progresses over time, and to encourage comments from the community. The benefit of this approach is two-fold: it allows for making a time-stamped document version with DOI publicly available, while the document continues to evolve on the PubPub platform and can subsequently be published again in updated form. It is thus representative of interative publishing workflows that are being adapted to suit the project, thus putting into practice as it does some of the principles behind COPIM.

The resulting [Scoping Report](https://doi.org/10.5281/zenodo.3961564) discusses the distribution of books via the traditional library supply and new forms of digital dissemination before investigating questions of metadata creation, and the types of provision available for these purposes. The findings are then synthesized in a number of key recommendations for WP5 that will inform the further development of [Thoth](https://github.com/thoth-pub), an open metadata system that will become part of the ODS that WP5 is working on. The recommendations of the scoping report have been integrated into the [GitHub development trajectory](https://github.com/thoth-pub/thoth/projects/1), and a [public Wiki](https://github.com/thoth-pub/thoth/wiki) has been set up to publicly document the different platforms and outputs Thoth aims to facilitate.

### Infrastructure Development

While WP5 does not have a formal infrastructure development deliverable scheduled for the project’s first year, it is noteworthy that the open metadata system that will form an integral part of the ODS has begun, with a first release to be made available by November 2020. This means that work on the major Year 2 deliverable is starting well ahead of time, with development now happening iteratively and following agile code development best practice. Project code and [general progress](https://github.com/thoth-pub/thoth/blob/master/CHANGELOG.md) of this development project are now made available in an open and transparent way via [GitHub](https://github.com/thoth-pub) and the [staging website](https://staging.thoth.openbookpublishers.com/).

## WP6. Experimental Publishing, Re-use and Impact

WP6 examines ways to align existing software, technologies, workflows and infrastructures for experimental publishing more closely with the workflow of open access book publishers and with the infrastructures that COPIM is endeavouring to create. It is producing a set of pilot cases of experimental books (including by ScholarLed presses Open Humanities Press and Mattering Press) which are developed with the aid of these new tools and technologies.

While Work Package 6 has seen a delay in filling open positions due to the pandemic and its impact on recruitment processes, the team has quickly gotten up to speed with working on its main outreach, research, and development goals.

### Outreach Activities & Community Building

The work package’s top priority was the successful organisation of an **experimental publishing workshop**. This event, organised by Coventry University, took place in early July 2020 and brought together some of the most cutting edge open source software and platform providers working on reimagining the academic book (including Manifold, Vega, thresholds, Hybrid Publishing Group, Scalar, PubPub and the Coko Foundation) with a selection of scholar-led and new university presses (including the ScholarLed presses, UCL Press, Goldsmiths Press, and the University of Westminster Press). The workshop participants collaboratively explored

-   a) how to stimulate and support the production and publication of >   experimental books;

-   b) the main inhibitions encountered with respect to the uptake of >   experimental publishing and reuse;

-   c) which kind of tools, platforms and infrastructures might be able to >   support experimental book publishing.

A [two](https://doi.org/10.21428/785a6451.8265afcb)-[part](https://copim.pubpub.org/pub/experimental-publishing-workshop-part-2) report reflecting on the outcomes of this workshop has also been published.

Next to the initial workshop, the work package team has conceptualised three pilot cases with Open Humanities Press (1) and Mattering Press (2), while a fourth pilot case with another press is currently being considered. For the first two pilot cases author communities in Mexico and the UK have already been engaged, and the cases, provisionally titled *ReRead/ReWrite* and *ComputingTheArchive* are currently being developed further while technical workflows are being devised together with the presses and the author communities. Author communities in Costa Rica and South Africa have also been engaged as part of potential further iterations of the pilot cases. The WP team will openly document the processes involved in these experiments, and the team will share their experiences via additional blog posts narrating the setting up of the first two pilot cases in the near future.

### Collaborative Research

WP6 has been working on a two-part scoping report. The first part of this report, based on desk research, provides a typology of different types and forms of scholarly books—based on various experiments currently being conducted within academia—accompanied by a selection of examples to illustrate each of the different types identified. The second part of this scoping report outlines the main technology and software developments currently taking place in experimental academic publishing. The publication of this report is currently facing a slight delay (expected M13 instead of M12) as it has been affected by the pandemic and resulting impact on staff recruitment.

A separate literature review outlining inhibitions around open access book content interaction and reuse and cultural strategies has also been developed which will feed into the research report on this topic due in Year 2.

### Infrastructure Development

To support the first two pilot cases, technical workflows are currently being developed to incorporate existing tool and technologies into the publishers’ workflows with the aid of the presses and author communities involved. This process will similarly be openly documented.

## WP7. Archiving and Digital Preservation

WP7 is working to identify the key challenges associated with archiving research monographs in all their variation and complexity and develop new solutions.

With a nominal start in May 2020, the work package has also seen delays in staff recruitment due to the impact of the pandemic on institutional processes.

### Outreach Activities & Community Building

While the delay in staff recruitment brought an associated delay to the outreach efforts planned, the work package has successfully organized its first Scoping Workshop. The workshop, which took place in September in close collaboration with the DPC, had the goal to bring together participants with expertise in web archives, research data, library repositories and scholarly publishing. A report summarizing the event is currently in development.

### Collaborative Research

While no finalized research output has been scheduled for Year 1, an initial literature review of existing projects, reports, and academic work on archiving and preservation of digital books is currently being produced. Closely related to that research is the collaboration with OPERAS, with a survey led by OPERAS colleagues that has now been set up, reaching out to all 56 members of the OPERAS community, covering 17 countries. Next to that, WP7 is reaching out to more stakeholders to conduct interviews in the following weeks.

### Infrastructure Development

The work package team has already begun scoping risks and challenges for preservation, with the aim to create a draft risk register and prioritisation list of challenges. Next to that, this first report will benefit from insight gained during the work package’s first scoping workshop on current best practice, and possible future developments, in preserving and archiving open access books. The report is now planned to be ready for publication by M13.

# Appendix

## Overview of progress, first year

| **Activities**                                                   | **Outputs**                                                                                                                       | **Month Due**                                | **Month Delivered**                       | **Reason for delay**                                                                        | **Mitigation strategy**                                                                                                                               |
|------------------------------------------------------------------|-----------------------------------------------------------------------------------------------------------------------------------|----------------------------------------------|-------------------------------------------|---------------------------------------------------------------------------------------------|-------------------------------------------------------------------------------------------------------------------------------------------------------|
| **Collaborative Research**                                       |                                                                                                                                   |                                              |                                           |                                                                                             |                                                                                                                                                       |
| WP2. Revenue Infrastructures and Management Platform             | Scoping Report (including Use Case Studies)                                                                                       | M6                                           | M13                                       | Impact of COVID-19 on staff recruitment, impact on team workload organization               | Re-alignment of team workload and workflows                                                                                                           |
|                                                                  | Workshop Reports                                                                                                                  | M8                                           | M7                                        | *n.a.*                                                                                      |                                                                                                                                                       |
| WP5. Building an Open Dissemination System                       | Scoping report (including use case studies and tech specs)                                                                        | M6                                           | M9                                        | Impact of COVID-19 on workflows, reduced availability of staff due to increased care duties | Re-alignment of team workload and workflows                                                                                                           |
| WP6. Experimental Publishing, Re-use and Impact                  | Scoping report on experimental book publishing software / platforms and integration                                               | M12                                          | M13 *(expected)*                          | Delay in recruiting researcher-developer                                                    | Developer working extra hours to catch up                                                                                                             |
| **Infrastructure Development**                                   |                                                                                                                                   |                                              |                                           |                                                                                             |                                                                                                                                                       |
| WP2. Revenue Infrastructures and Management Platform             | Design Specs                                                                                                                      | M9                                           | M12 *(expected by the end of this month)* | Delay in setting up external contractor with one of the partners                            | Re-alignment of team workload and workflows                                                                                                           |
| WP7. Archiving and Digital Preservation                          | Use cases and technical specification                                                                                             | M9                                           | M12 *(expected by the end of this month)* | Delay in staff recruitment                                                                  |                                                                                                                                                       |
| **Outreach Activities & Community Building**                     |                                                                                                                                   |                                              |                                           |                                                                                             |                                                                                                                                                       |
| WP2. Revenue Infrastructures and Management Platform             | 2x Stakeholder Workshop                                                                                                           | M2 & M5                                      | M5 & M7                                   | Onset of the pandemic                                                                       | Re-structuring of workshop organisation, switch to online-only events                                                                                 |
| WP3. Knowledge Exchange and Piloting Alternative Business Models | Workshop for Stakeholder Identification                                                                                           | M7                                           | M5                                        | *n.a.*                                                                                      |                                                                                                                                                       |
| WP4. Community Governance                                        | Stakeholder Workshop                                                                                                              | M7                                           | M7                                        | *n.a.*                                                                                      |                                                                                                                                                       |
|                                                                  | Assembly of a publisher-librarian working group for the long-term direction and management of consortial library funding programs | M12                                          | M8                                        |                                                                                             |                                                                                                                                                       |
| WP5. Building an Open Dissemination System                       | 2x Scoping Workshop                                                                                                               | M2 & M5                                      | M5                                        | Second workshop rescheduled to Year 2                                                       | Re-prioritization due to advances in the development portion of the WP, second workshop envisioned to collect feedback on first version of test case. |
| WP6. Experimental Publishing, Re-use and Impact                  | Workshop with experimental book software/platform providers and OA book publishers                                                | M7                                           | M9                                        | Slight delay due to reconfiguring to online due to pandemic                                 |                                                                                                                                                       |
| WP7. Archiving and Digital Preservation                          | Scoping workshop in partnership with DPC                                                                                          | M7                                           | M11                                       | Delay in staff recruitment                                                                  |                                                                                                                                                       |
| **Public Engagement**                                            |                                                                                                                                   |                                              |                                           |                                                                                             |                                                                                                                                                       |
| Project Website                                                  | *Ongoing*                                                                                                                         | see *List of Output* as part of the Appendix |                                           |                                                                                             |                                                                                                                                                       |
| Social Media promotion                                           |                                                                                                                                   |                                              |                                           |                                                                                             |                                                                                                                                                       |
| Blog posts and press articles                                    |                                                                                                                                   |                                              |                                           |                                                                                             |                                                                                                                                                       |
| Free public events                                               |                                                                                                                                   |                                              |                                           |                                                                                             |                                                                                                                                                       |

## Outcomes: performance against Key Performance Indicators (KPI)

For a detailed overview in support of the KPIs, please see section *Outputs*

|                                                    | **Measurable impact**                                                                                         |                     |
|----------------------------------------------------|---------------------------------------------------------------------------------------------------------------|---------------------|
| **Set-up phase**                                   | Governance body and management arrangements established                                                       | ✅                   |
| **Revenue Infrastructure and management platform** | Key stakeholders engaged (to include publishers, knowledge managers and librarians) (Y1)                      | ✅                   |
|                                                    | 160 libraries enrolled to the CL funding platform (Y3)                                                        |                     |
|                                                    | £150,00 revenue generated by the platform (Y3)                                                                |                     |
|                                                    | Technical methods for the robust archiving of complex digital books (Y3)                                      |                     |
|                                                    | Outreach program to the international library community developed (Y1)                                        | ✅                   |
|                                                    | Finalised model for community-owned OA revenue programme for books (Y2)                                       |                     |
|                                                    | Launch of the ScholarLed revenue platform pilot (Y3)                                                          |                     |
| **Community Building**                             | 250+ libraries and publishers internationally briefed about COPIM (Y3)                                        | 120+ (Y1)           |
|                                                    | Governing body for digital infrastructure & assets (Y2)                                                       |                     |
|                                                    | 2 non-OA publishers migrate their economic models to OA hospitable versions (Y3)                              |                     |
|                                                    | 3 experimental publications with the COPIM infrastructure (Y3)                                                |                     |
|                                                    | On-line toolkit for booting up and running an OA press (Y3)                                                   |                     |
| **Dissemination Activities**                       | Project website established (Y1)                                                                              | ✅                   |
|                                                    | 1m online interactions (through the project website, twitter and blog posts) (Y3)                             | \+300k reached (Y1) |
|                                                    | Presenting the results of COPIM research at 30 international publishing, library and HSS research conferences |                     |
|                                                    | 26 stakeholder workshops (Y3)                                                                                 | 11 (Y1)             |
|                                                    | 3 international conferences (Y3)                                                                              |                     |
|                                                    | 5 ScholarLed member presses Implementing the Open Dissemination System workflow (Y3)                          |                     |
|                                                    | Manual on professionalising a small scholar-led press (Y2)                                                    |                     |
|                                                    | 5,000+ members of public have been informed of COPIM and OA Books (Y3)                                        |                     |

## List of generated Outputs

| Type                                        | Title                                                                                              | Date publ. | Link / DOI                                                                                    | License          | Usage\*                      |
|---------------------------------------------|----------------------------------------------------------------------------------------------------|------------|-----------------------------------------------------------------------------------------------|------------------|------------------------------|
| Scoping Reports                             |                                                                                                    |            |                                                                                               |                  |                              |
| Deliverable - Report WP5                    | WP5 Scoping Report: Building an Open Dissemination System                                          | 27/07/2020 | [10.5281/zenodo.3961563](https://doi.org/10.5281/zenodo.3961563)                              | CC BY 4.0        | Zenodo: 317 views / 134 DL   |
|                                             |                                                                                                    |            |                                                                                               |                  | PubPub: 626 views / 68 DL    |
| Deliverable - Report WP3                    | COPIM – Revenue Models for Open Access Monographs 2020                                             | 07/09/2020 | [10.5281/zenodo.4011835](https://doi.org/10.5281/zenodo.4011835)                              | CC BY 4.0        | Zenodo: 1,478 views / 650 DL |
| Workshop Reports                            |                                                                                                    |            |                                                                                               |                  |                              |
| Milestone - Workshop Report WP2             | COPIM Publishers Workshop: Collaborative Library Support and Archival Processes                    | 15/04/2020 | [10.21428/785a6451.93d20bd2](https://doi.org/10.21428/785a6451.93d20bd2)                      | CC BY 4.0        | PubPub: 99views              |
| Milestone - Workshop Report WP2             | WP2 Workshop in Partnership with University of Michigan, MPublishing, and Lyrasis                  | 25/05/2020 | [10.21428/785a6451.c6005f3a](https://doi.org/10.21428/785a6451.c6005f3a)                      | CC BY 4.0        | PubPub: 49views              |
| Milestone - Workshop Report WP3             | COPIM Publishers Workshop: Cost and Revenue Models                                                 | 15/04/2020 | [10.21428/785a6451.c77576a6](https://doi.org/10.21428/785a6451.c77576a6)                      | CC BY 4.0        | PubPub: 106 views            |
| Milestone - Workshop Report WP4             | COPIM Community Governance Workshop Recap: Part 1                                                  | 25/05/2020 | [10.21428/785a6451.6a3a2ca2](https://doi.org/10.21428/785a6451.6a3a2ca2)                      | CC BY 4.0        | PubPub: 186 views            |
| Milestone - Workshop Report WP4             | COPIM Community Governance Workshop Recap: Part 2 - On the Meaning of Community                    | 15/06/2020 | [10.21428/785a6451.dfe7dc68](https://doi.org/10.21428/785a6451.dfe7dc68)                      | CC BY 4.0        | PubPub: 134 views            |
| Milestone - Workshop Report WP5             | COPIM Publishers Workshop: Discovery & dissemination — the present                                 | 15/04/2020 | [10.21428/785a6451.3cc46720](https://doi.org/10.21428/785a6451.3cc46720)                      | CC BY 4.0        | PubPub: 76 views             |
| Milestone - Workshop Report WP5             | COPIM Publishers Workshop: Discovery & dissemination — the future                                  | 15/04/2020 | [10.21428/785a6451.4657252e](https://doi.org/10.21428/785a6451.4657252e)                      | CC BY 4.0        | PubPub: 68 views             |
| Workshop Report WP2                         | Library Support for OA Books Workshop: the German perspective.                                     | 06/08/2020 | [10.21428/785a6451.91ef1b29](https://doi.org/10.21428/785a6451.91ef1b29)                      | CC BY 4.0        | PubPub: 220 views            |
| Workshop Report WP2                         | Library Support for OA Books Workshop: the Polish perspective.                                     | 23/09/2020 | [10.21428/785a6451.5af83711](https://doi.org/10.21428/785a6451.5af83711)                      | CC BY 4.0        | PubPub: 126 views            |
| Workshop Report WP2                         | Library Support for OA Books Workshop: the Scandinavian perspective.                               | 06/10/2020 | [10.21428/785a6451.ebae812c](https://doi.org/10.21428/785a6451.ebae812c)                      | CC BY 4.0        | PubPub: 98 views             |
| Workshop Report WP2                         | Library Support for OA Books Workshop: the South European perspective.                             | 12/10/2020 | [10.21428/785a6451.c1cd7059](https://doi.org/10.21428/785a6451.c1cd7059)                      | CC BY 4.0        | PubPub: 112 views            |
| Workshop Report WP2                         | Sketching a direction of travel: An update from Work Package 2                                     | 23/10/2020 | [10.21428/785a6451.a0537c6d](https://doi.org/10.21428/785a6451.a0537c6d)                      | CC BY 4.0        | PubPub: ? views              |
| Workshop Report WP6                         | COPIM Experimental Publishing Workshop - Part 1: Inhibitions Towards Experimental Book Publishing. | 19/10/2020 | [10.21428/785a6451.8265afcb](https://doi.org/10.21428/785a6451.8265afcb)                      | CC BY 4.0        | PubPub: ? views              |
| Workshop Report WP6                         | COPIM Experimental Publishing Workshop - Part 2: Promoting Experimental Publishing.                | 20/10/2020 | [10.21428/785a6451.a21d57b6](https://doi.org/10.21428/785a6451.a21d57b6)                      | CC BY 4.0        | PubPub: ? views              |
| Workshop Report WP7                         | Joint COPIM and DPC workshop: The Technical Issues of Archiving Third-Party Material in OA Books   |            | tbc                                                                                           | tbc              | tbc                          |
| Blog posts                                  |                                                                                                    |            |                                                                                               |                  |                              |
| Outreach                                    | Moving a workshop online: what works and what doesn’t?                                             | 26/03/2020 | [10.21428/785a6451.370f67b5](https://doi.org/10.21428/785a6451.370f67b5)                      | CC BY 4.0        | PubPub: 372 views            |
| Outreach                                    | Using PubPub for scholarly output: Import, Collaboration, Citations, and Zotero                    | 26/07/2020 | [10.21428/785a6451.f72bab42](https://doi.org/10.21428/785a6451.f72bab42)                      | *CC* BY 4.0      | *PubPub:* 281 views          |
| Outreach                                    | COPIM FAQ                                                                                          | 15/01/2020 | [10.21428/785a6451.13be85b7](https://doi.org/10.21428/785a6451.13be85b7)                      | CC BY 4.0        | PubPub: 316 views            |
| Outreach                                    | An Introduction to our Documentation Site                                                          | 04/11/2019 | [10.21428/785a6451.87ca0615](https://doi.org/10.21428/785a6451.87ca0615)                      | CC BY 4.0        | PubPub: 316 views            |
| Outreach / WP1                              | COPIM Kicks Off in Coventry                                                                        | 16/01/2020 | [10.21428/785a6451.105afcdb](https://doi.org/10.21428/785a6451.105afcdb)                      | CC BY 4.0        | PubPub: 121 views            |
| Outreach / WP1                              | COPIM Newsflash! \#2 Project Update June 2020                                                      | 22/06/2020 | [10.21428/785a6451.cd14eb38](https://doi.org/10.21428/785a6451.cd14eb38)                      | CC BY 4.0        | PubPub: 218 views            |
| Outreach / WP2                              | COPIM Newsflash! Project Update March 2020                                                         | 31/03/2020 | [10.21428/785a6451.b16436b6](https://doi.org/10.21428/785a6451.b16436b6)                      | CC BY 4.0        | PubPub: 208 views            |
| WP1                                         | COPIM's response to the UKRI OA Consultation                                                       | 05/06/2020 | [10.21428/785a6451.9e58d1d8](https://doi.org/10.21428/785a6451.9e58d1d8)                      | CC BY 4.0        | PubPub: 186 views            |
| WP3                                         | Changed priorities ahead: scholarly publishing and Covid-19                                        | 17/08/2020 | [PubPub link](https://copim.pubpub.org/pub/changed-priorities-ahead/)                         | CC BY 4.0        | PubPub: 195 views            |
| WP3                                         | Sharing knowledge in COPIM and beyond                                                              | 17/09/2020 | [PubPub link](https://copim.pubpub.org/pub/sharing-knowledge/)                                | CC BY 4.0        | PubPub: 116 views            |
| WP3                                         | New report released today: Revenue Models for OA Monographs 2020                                   | 08/09/2020 | [PubPub link](https://copim.pubpub.org/pub/wp3-report-revenue-models-for-oa-monographs-2020/) | CC BY 4.0        | PubPub: 458 views            |
| WP3                                         | Work Package 3: Transitioning the Central European University Press to Open Access                 | 22/10/2020 | [10.21428/785a6451.e2cecca6](https://doi.org/10.21428/785a6451.e2cecca6)                      | CC BY 4.0        | PubPub: ? views              |
| WP4                                         | Community Governance Explored                                                                      | 24/07/2020 | [10.21428/785a6451.20a5c646](https://doi.org/10.21428/785a6451.20a5c646)                      | CC BY 4.0        | PubPub: 310 views            |
| WP6                                         | Thinking Experimental Publishing: introducing COPIM Work Package 6                                 | 23/07/2020 | [PubPub link](https://copim.pubpub.org/pub/introducing-copim-work-package-6/)                 | CC BY 4.0        | PubPub: 126 views            |
| Code, datasets and technical specifications |                                                                                                    |            |                                                                                               |                  |                              |
| Code repository                             | Toth - Open Metadata System                                                                        |            | [github.com/thoth-pub](https://github.com/thoth-pub)                                          | code: Apache 2.0 |                              |
|                                             |                                                                                                    |            |                                                                                               | metadata: CC0    |                              |
| Wiki                                        | Technical Specifications                                                                           |            | [github.com/thoth-pub/thoth/wiki](https://github.com/thoth-pub/thoth/wiki)                    | CC BY 4.0        |                              |

## Risk Register (updated to reflect Year 1 developments)

| **Risk**                                                                                                                                                                                                                                                                                                                                     | **Probability & Impact** | **Mitigation**                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   |
|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|--------------------------|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| **Management Risks**                                                                                                                                                                                                                                                                                                                         |                          |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  |
| Key staff leaves the project                                                                                                                                                                                                                                                                                                                 | M/M                      | Recruit new staff from the extended community established around the consortium. Principles for the storing, sharing, and archiving of ongoing work will be agreed at the beginning of the project and all activities will be thoroughly documented.                                                                                                                                                                                                                                                                                                                                                                                                                                                                             |
| Inability to recruit qualified personnel                                                                                                                                                                                                                                                                                                     | H/H                      | Project partners will widely advertise these positions in their networks. Potentially suitable candidates have already been identified and will be encouraged to apply.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| Failure of partner to complete tasks                                                                                                                                                                                                                                                                                                         | L/H                      | Depending on the situation leading to the partner not performing to expectations, alternative remedial actions will vary from other partners offering assistance, initiation of project task forces, and in the extreme case replacing the partner. Provisions for dealing with non-performing contractors and penalties for non-compliance with obligations will be governed by the consortium agreement.                                                                                                                                                                                                                                                                                                                       |
| Lack of coordination between work packages. The complexity of project causes inter-dependencies between work packages to jam                                                                                                                                                                                                                 | M/M                      | Dedicated full-time Project Manager (PM). Dedicated WP to coordinate activities, led by the Management Team (MT) (PI and Co-I). Regular management meetings across all 3 governance tiers: (1) bi-weekly meetings of the MT with the PM; (2) monthly meetings between MT, PM, and WP leaders; (3) monthly meetings of the Senior Management Committee (SMC); (4) yearly meetings with the International Advisory Board. Effective lines of communication (Slack, Skype). Use of project management tools. If necessary, frequency of meetings will be increased to quickly address project drift. Swift corrective measures will be recorded and actioned to ensure progress is maintained and will be reviewed at SMC Meetings. |
| **Implementation Risks**                                                                                                                                                                                                                                                                                                                     |                          |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  |
| Insufficient number of libraries subscribing to the COPIM consortial library funding platform                                                                                                                                                                                                                                                | M/H                      | Additional incentives in the form of expert advice for new members and additional workshops to promote the new funding platform will be offered. Identification and development of new channels to maximize communication and acceptance. Funding from the Arcadia Trust will account for the extra costs of such activities.                                                                                                                                                                                                                                                                                                                                                                                                    |
| Competition from well-established consortial library funding models for OA books (e.g. Knowledge Unlatched)                                                                                                                                                                                                                                  | M/M                      | i) Early engagement with libraries and presses through requirements collection; (ii) extensive outreach programme to present the COPIM infrastructure and its unique features (deploying the Advisory Board); (iii) analysis of competition to improve COPIM’s unique selling points; (iv) support from Coventry University’s Enterprise team on business development for COPIM.                                                                                                                                                                                                                                                                                                                                                 |
| Dissemination Pilot: Publishers reluctant to share information about their business models delaying requirement collection.                                                                                                                                                                                                                  | H/H                      | Tap into the network of presses established by COPIM publishing partners. Clear signaling in advance that support from business modellers is conditional on internal disclosure of finances. Upfront negotiation on degree of disclosure that is permissible in final outputs. Increase outreach activities to establish trust across scholar-led presses.                                                                                                                                                                                                                                                                                                                                                                       |
| Problems engaging with the appropriate stakeholder representatives (libraries, publishers and scholars) to establish a governance community                                                                                                                                                                                                  | M/H                      | i)The COPIM consortium includes all major stakeholders in academic book publishing that will constitute the kernel of the governance community; (ii) project activities are designed to tap into the partners extensive networks and contacts to attract key stakeholders; (iii) work with the international Advisory Board to enroll key stakeholders. Review of outreach activities to customise them to feedback from participants.                                                                                                                                                                                                                                                                                           |
| Failure to scale up the COPIM consortial library model across presses and libraries to ensure sustainability                                                                                                                                                                                                                                 | M/H                      | Existing partners in WP are well positioned to facilitate well designed project and adoption by broader community. Engagement and compatibility of system design with existing and robust community of open source software, such as that for Linked Open Datasets, will also mitigate this risk.                                                                                                                                                                                                                                                                                                                                                                                                                                |
| Open Dissemination System: inability to grow a community around the metadata standards developed by COPIM                                                                                                                                                                                                                                    | M/M                      | The COPIM consortium constitutes the core of a growing OA ecosystem for monographs. The dissemination and advocacy workshops and community building activities are designed to found a dynamic and mutually supportive digital preservation community to adopt and disseminate the metadata standards of the ODS.                                                                                                                                                                                                                                                                                                                                                                                                                |
| Open Archiving System: inability to grow a community of repositories and publishers around the standards and protocols developed by COPIM.                                                                                                                                                                                                   | M/H                      | The community of libraries and publishers developed through the whole COPIM project will facilitate broader community adoption. Creation of detailed user case studies and associated technical specification for effective archiving of alternative content types will ensure appropriate processes are developed for well-defined content. Involvement and expertise of existing digital archiving community within the Digital Archiving Coalition will also be mitigate this risk. Expert advice and support offered during the outreach programme will help overcome technical barriers to community growth.                                                                                                                |
| Cultural barriers too high to overcome where it concerns experimental book publishing and reuse of and engagement with OA books                                                                                                                                                                                                              | M/H                      | Dedicated WP to address user needs and requirements. Increase of outreach activities to authors and OA book publishers. Development of an online resource on experimental publishing and a reuse and engagement strategy for OA presses and scholars                                                                                                                                                                                                                                                                                                                                                                                                                                                                             |
| **Technical Risks**                                                                                                                                                                                                                                                                                                                          |                          |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  |
| Software development experiences growth of requirements                                                                                                                                                                                                                                                                                      | M/H                      | (i) Early information on user requirements' fulfilment; (ii) systematic prioritisation of requirements; (iii) impact assessment of new requirements proposed by the users and decision whether to implement it or not.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           |
| Quality deviations in infrastructure components                                                                                                                                                                                                                                                                                              | M/H                      | (i) Notification of WP leader, PM and SMC, (ii) Analysis of impact on project. The SMC decides on and initiates contingency plan depending on severity of deviation & impact on project.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         |
| Consortial library platform: Presses encounter difficulties in revising existing business models or meeting technical requirements delaying implementation or dropping out of the pilot                                                                                                                                                      | M/H                      | Possible delays to implementation will be addressed by (i) systematic review of technical requirements during project meetings; (ii) establishment of feedback mechanisms for presses to review requirements; (iii) early identification of a second group of presses that could join the pilot; (iv) recruitment of additional presses through partner networks                                                                                                                                                                                                                                                                                                                                                                 |
| Open Dissemination System: Failure to adequately incorporate the technical requirements from across all stakeholders in scholarly dissemination channels (including compliance with future policy, e.g. Plan S)                                                                                                                              | M/H                      | Collaborative work with major stakeholders to develop well-documented “use cases”, which will form the basis for the subsequent specification of development objectives. Assignment of suitable “product owners” from appropriate stakeholder groups for each development package. Partners’ commitment to implement the ODS packages developed.                                                                                                                                                                                                                                                                                                                                                                                 |
| Open Dissemination System: 3rd party discovery and dissemination channels may change their specifications, processes or acceptance criteria. New discovery channels will emerge over time.                                                                                                                                                   | H/H                      | The modular design will ensure that separate code is developed for alternative discovery and dissemination channels, and these can easily be updated or added to as new channels and processes emerge without disrupting the entire platform. Designing and implementing a sustainable revenue stream to cover these ongoing maintenance costs will be conducted in conjunction with WPs 2 & 3.                                                                                                                                                                                                                                                                                                                                  |
| Open Dissemination System: Without ongoing maintenance, the ODS will progressively become ineffective.                                                                                                                                                                                                                                       |                          |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  |
| Technical Debt: Adoption by publishers of processes developed in WPs 5 & 7 may be difficult given the publishers’ existing technical design. Adapting or revising existing process and data management structures may be difficult and/or be undertaken gradually - delaying or preventing adoption.                                         | H/H                      | The modular design and use of proxy servers allow for components of the systems to be adopted gradually, rather than requiring a wholesale reform of all processes. In addition, the system will be designed to allow either selfhosted systems for publishers or publishers utilising a third-party provider (at least in the interim). Emphasis will be made on creating systems for adoption with new publications - allowing backlist content to be included gradually. Developing processes and documentation for adoption by partner publishers will ensure many of these difficulties are recognised and incorporated into the design and development processes.                                                          |
| Experimental Publishing Pilot: Inability to integrate experimental books into the COPIM infrastructure (particularly WPs 5 & 7).                                                                                                                                                                                                             | M/H                      | (i) Early collection of requirements from experimental books publishers, platforms and software providers to feed into technical specifications of other work packages; (ii) meticulous design of archiving and digital preservation guidelines to be fit for purpose as part of WP7; Dedicated developer in WP6.                                                                                                                                                                                                                                                                                                                                                                                                                |
| [added Feb 2020] Consortial library platform: changes in development partner (from internal hire to external partner [Cast Iron Coding])[^5]                                                                                                                                                                                                 | M/H                      | (i) Ensuring terms of relationship are established clearly from the outset, managed via appropriate contracts and data sharing agreements; (ii) working with project team at an early stage to identify alternative development partners to be approached if Cast Iron Coding are no longer able to work on the project, to ensure the project has redundancy when it comes to development partners.                                                                                                                                                                                                                                                                                                                             |
| [added May 2020] Consortial library platform: inability to fulfil all requirements hoped for by libraries/publishers within budget                                                                                                                                                                                                           | M/H                      | (i) Ensuring that research with publishers includes working on lists of desired features ranked by priority, and discussing different development with them at an early stage in order to (a) manage expectations and (b) explore the feasibility of different solutions; (ii) ensuring development is focused on modular solutions that can be scaled up further in the future should further funding routes be identified.                                                                                                                                                                                                                                                                                                     |
| [added May 2020] Cancelling of in-person participation, reduced or nonavailability of expert informants could further impact on research                                                                                                                                                                                                     | H/H                      | Switch to online, reformulation of research questions, overall restructuring of engagement approach                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |
| [added May 2020] Reduced engagement of project staff: A noticeable increase in other duties (e.g. looking after dependants) due to quarantine might impact ability to be involved in work packages                                                                                                                                           | M/H                      | a) Other network partners need to take on duties, b) considering to temporarily halt parts of the project,  both options might in turn result in a need to extend the overall project.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           |
| [added May 2020] Recruitment: Even more difficulty to find suitable specialist applicants willing to work in UK-based project                                                                                                                                                                                                                | M/H                      | Redistribution of workload to existing network, which may in turn impact on overall outcome. An extension of the project end date could help to mitigate delays in the hiring process.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           |
| [added May 2020] Outreach: participation in external workshops & conferences, i) Diminished overall networking activities, as conferences are being cancelled, which impacts COPIM presentations. ii) Impact on deliverables and Key Success Criteria, as the original number of conferences/workshops COPIM participates in will not be met | H/H                      | Explore other channels of engagement (e.g. social media)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         |
| [added Aug 2020] Covid-19 pandemic causes cuts in funding for HE institutions and library budgets - libraries unable/unwilling to contribute to WP3 case study membership subscriptions.                                                                                                                                                     | M/H                      | Increase advocacy/marketing and emphasise that libraries traditionally subscribe to access content - to show that this model fits alongside their existing processes. Emphasise that collective funding models are not expensive and also that, in subscribing, libraries are contributing positively to the wider open access agenda. Highlight that Covid-19 pandemic has thrown a spotlight on the importance and merit of OA and digital books. Make the model offered as frictionless as possible: make it and the benefits easy to articulate, and ensure it is a high value offer delivering value for money.                                                                                                             |


## Project images for re-use and dissemination

![](media/c3ecaa7824c212676fdc6ae7d41fccf6.jpeg)

Figure 1: Project Kick-Off \@ Coventry University, Jan 10, 2020. Image credit: Paul Henderson, 2020. [CC BY 4.0](https://creativecommons.org/licenses/by/4.0/deed.ast).

![](media/f59f6758ab7200e378bae4b110cdc48c.png)

Figure 2: Infographic - COPIM Outreach, Year 1. Image credit: COPIM, 2020. [CC BY 4.0](https://creativecommons.org/licenses/by/4.0/deed.ast).

---

END  
